.. noload documentation master file, created by
   sphinx-quickstart on Fri May 28 17:14:25 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NoLOAD_Jax's documentation!
======================================

Introduction to NoLOAD_Jax
--------------------------
NoLOAD_Jax stands for Non-Linear Optimization using Automatic Differentiation
with Jax package.
It aims to be a light non-linear optimization tool for energy components and
systems.
It is an Open Source project located on GitLab at `NoLOAD Gitlab`_, with
available open benchmark examples at `NoLOAD benchmark Gitlab`_

Contents
--------
.. toctree::
   :maxdepth: 2

   about_NoLOAD_Jax

.. toctree::
   :maxdepth: 1

   installation_requirements

.. toctree::
   :maxdepth: 2

   how_to_NoLOAD_Jax

.. toctree::
   :maxdepth: 2

   dynamic_systems_optim

.. toctree::
   :maxdepth: 2

   NoLOAD_Jax_description

.. toctree::
   :maxdepth: 2

   new_functionnalities

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

NoLOAD_Jax in scientific publications
-------------------------------------

NoLOAD_Jax appears in the following scientific publications :

- Agobert, L., Gerbaud, L., & Delinchant, B. (2025). Optimization with Time and Frequency Constraints Using Automatic Differentiation: Application to an Aircraft Electrical Power Channel. Applied Sciences, 15(7), 3624. https://doi.org/10.3390/app15073624
- Lucas Agobert, Benoit Delinchant, Laurent Gerbaud. Optimization on frequency constraints with FFT using Automatic Differentiation on hybrid ODE applications. COMPEL: The International Journal for Computation and Mathematics in Electrical and Electronic Engineering, 2024, 43 (4), pp.821-838.
- Agobert, L., Hodencq, S., Delinchant, B., Gerbaud, L., & Frederic, W. (2021, September). NoLOAD, Open Software for Optimal Design and Operation using Automatic Differentiation. In OIPE2020-16th International Workshop on Optimization and Inverse Problems in Electromagnetism.
- Hodencq, Sacha, Benoit Delinchant, and Frederic Wurtz. "Vers l'ouverture des modeles d'optimisation de systemes energetiques pour l'Analyse de Cycle de Vie: cas d'etude d'un foyer en autoconsommation photovoltaique avec l'outil open source NoLOAD." SYMPOSIUM DE GENIE ELECTRIQUE (SGE 2020). 2020.
- Hodencq, Sacha, Benoit Delinchant, and Wurtz Frederic. "Open and Reproducible Use Cases for Energy (ORUCE) methodology in systems design and operation: a dwelling photovoltaic self-consumption example." Building Simulation 2021. 2021.

Acknowledgments
---------------

A special thank is adressed to the contributors that are not main authors, such as Manh Tung Phan for the IHM (Human-Machine Interaction.)


.. _NoLOAD Gitlab: https://gricad-gitlab.univ-grenoble-alpes.fr/design_optimization/NoLoad_v2
.. _NoLOAD benchmark Gitlab: https://gricad-gitlab.univ-grenoble-alpes.fr/design_optimization/noload_benchmarks_open/-/tree/noload_version2
